@@ -1,5 +1,3 @@
-from __future__ import absolute_import, division, print_function, with_statement
-
 import sys
 import os
 
@@ -45,8 +43,8 @@ def debugger(self, force=False):
     if not (force or self.call_pdb):
         return
 
-    if not hasattr(sys, 'last_traceback'):
-        error('No traceback has been produced, nothing to debug.')
+    if not hasattr(sys, "last_traceback"):
+        error("No traceback has been produced, nothing to debug.")
         return
 
     from pudb import pm
