@@ -156,11 +156,11 @@ class StackFrame(urwid.FlowWidget):
             crnt_pfx = "   "
 
         text = crnt_pfx+self.name
-        attr = [(apfx+"frame name", 3+len(self.name))]
+        attr = [(apfx+"frame name", 4+len(self.name))]
 
         if self.class_name is not None:
             text += " [%s]" % self.class_name
-            attr.append((apfx+"frame class", len(self.class_name)+3))
+            attr.append((apfx+"frame class", len(self.class_name)+2))
 
         loc = " %s:%d" % (self.filename, self.line)
         text += loc
@@ -204,9 +204,9 @@ class BreakpointFrame(urwid.FlowWidget):
         bp_pfx = bp_pfx.ljust(3)
 
         hits_label = "hits" if self.hits != 1 else "hit"
-        loc = " %s:%d (%s %s)" % (self.filename, self.line, self.hits, hits_label)
+        loc = f" {self.filename}:{self.line} ({self.hits} {hits_label})"
         text = bp_pfx+loc
-        attr = [(apfx+"breakpoint", len(loc))]
+        attr = [(apfx+"breakpoint", len(text))]
 
         return make_canvas([text], [attr], maxcol, apfx+"breakpoint")
 
